@@ -9,7 +9,7 @@ from grpc._cython import cygrpc
 
 from ..grpc_gen import milvus_pb2_grpc
 from ..grpc_gen import milvus_pb2 as grpc_types
-from .abstract import ConnectIntf, CollectionSchema, IndexParam, PartitionParam, TopKQueryResult, CollectionInfo
+from .abstract import ConnectIntf, CollectionSchema, IndexParam, PartitionParam, TopKQueryResult, HEntitySet
 from .prepare import Prepare
 from .types import MetricType, Status
 from .check import (
@@ -21,7 +21,7 @@ from .check import (
 from .asynch import SearchFuture, InsertFuture, CreateIndexFuture, CompactFuture, FlushFuture
 
 from .hooks import BaseSearchHook
-from .client_hooks import SearchHook
+from .client_hooks import SearchHook, HybridSearchHook
 from .exceptions import ParamError, NotConnectError
 from ..settings import DefaultConfig as config
 from . import __version__
@@ -111,6 +111,7 @@ class GrpcHandler(ConnectIntf):
 
         # client hook
         self._search_hook = SearchHook()
+        self._hybrid_search_hook = HybridSearchHook()
         self._search_file_hook = SearchHook()
 
         # set server uri if object is initialized with parameter
@@ -275,6 +276,15 @@ class GrpcHandler(ConnectIntf):
         LOGGER.error(status)
         return Status(code=status.error_code, message=status.reason)
 
+    @error_handler()
+    def create_hybrid_collection(self, collection_name, fields, timeout=10):
+        collection_schema = Prepare.collection_hybrid_schema(collection_name, fields)
+        response = self._stub.CreateHybridCollection(collection_schema)
+        if response.error_code == 0:
+            return Status(message='Create collection successfully!')
+
+        return Status(code=response.error_code, message=response.reason)
+
     @error_handler(False)
     def has_collection(self, collection_name, timeout=10):
         """
@@ -410,6 +420,13 @@ class GrpcHandler(ConnectIntf):
         status = self._stub.PreloadCollection.future(collection_name).result(timeout=timeout)
         return Status(code=status.error_code, message=status.reason)
 
+    @error_handler()
+    def reload_segments(self, collection_name, segment_ids, timeout=10):
+        file_ids = list(map(int_or_str, segment_ids))
+        request = Prepare.reload_param(collection_name, file_ids)
+        status = self._stub.ReloadSegments.future(request).result(timeout=timeout)
+        return Status(code=status.error_code, message=status.reason)
+
     @error_handler()
     def drop_collection(self, collection_name, timeout=20):
         """
@@ -485,6 +502,15 @@ class GrpcHandler(ConnectIntf):
 
         return Status(code=response.status.error_code, message=response.status.reason), []
 
+    @error_handler([])
+    def insert_hybrid(self, collection_name, entities, vector_entities, ids=None, tag=None, params=None):
+        insert_param = Prepare.insert_hybrid_param(collection_name, tag, entities, vector_entities, ids, params)
+        response = self._stub.InsertEntity(insert_param)
+        status = response.status
+        if status.error_code == 0:
+            return Status(message='Insert successfully!'), list(response.entity_id_array)
+        return Status(code=status.error_code, message=status.reason), []
+
     @error_handler([])
     def get_vectors_by_ids(self, collection_name, ids, timeout=10):
         request = grpc_types.VectorsIdentity(collection_name=collection_name, id_array=ids)
@@ -503,6 +529,15 @@ class GrpcHandler(ConnectIntf):
 
         return Status(code=status.error_code, message=status.reason), []
 
+    @error_handler([])
+    def get_hybrid_entity_by_id(self, collection_name, ids):
+        request = grpc_types.VectorsIdentity(collection_name=collection_name, id_array=ids)
+        response = self._stub.GetEntityByID(request)
+
+        if response.status.error_code == 0:
+            return Status(), HEntitySet(response)
+        return Status(response.status.error_code, response.status.reason), []
+
     @error_handler([])
     def get_vector_ids(self, collection_name, segment_name, timeout=10):
         request = grpc_types.GetVectorIDsParam(collection_name=collection_name, segment_name=segment_name)
@@ -721,6 +756,30 @@ class GrpcHandler(ConnectIntf):
         resutls = self._search_hook.handle_response(response)
         return Status(message='Search vectors successfully!'), resutls
 
+    @error_handler(None)
+    def search_hybrid_pb(self, collection_name, query_entities, partition_tags, params=None, **kwargs):
+        request = Prepare.search_hybrid_pb_param(collection_name, query_entities, partition_tags, params)
+        response = self._stub.HybridSearchPB(request)
+
+        if response.status.error_code != 0:
+            return Status(code=response.status.error_code,
+                          message=response.status.reason), []
+
+        return Status(message='Search vectors successfully!'), \
+               self._hybrid_search_hook.handle_response(response)
+
+    @error_handler(None)
+    def search_hybrid(self, collection_name, vector_params, dsl, partition_tags=None, params=None, **kwargs):
+        request = Prepare.search_hybrid_param(collection_name, vector_params, dsl, partition_tags, params)
+        response = self._stub.HybridSearch(request)
+
+        if response.status.error_code != 0:
+            return Status(code=response.status.error_code,
+                          message=response.status.reason), []
+
+        return Status(message='Search vectors successfully!'), \
+               self._hybrid_search_hook.handle_response(response)
+
     @error_handler(None)
     def search_by_ids(self, collection_name, ids, top_k, partition_tags=None, params=None, timeout=None, **kwargs):
         request = Prepare.search_by_ids_param(collection_name, ids, top_k, partition_tags, params)
