@@ -10,17 +10,7 @@ from .grpc_handler import GrpcHandler
 from .http_handler import HttpHandler
 from milvus.client.exceptions import ConnectionPoolError, NotConnectError, VersionError
 
-support_versions = ['0.9.x', '0.10.x']
-
-
-def _is_version_match(version):
-    version_prefix = version.split(".")
-    for sv in support_versions:
-        support_version_prefix = sv.split(".")
-        if version_prefix[0] == support_version_prefix[0] and version_prefix[1] == support_version_prefix[1]:
-            return True
-
-    return False
+support_versions = ('0.9.0', '0.9.1', '0.10.0')
 
 
 class Duration:
@@ -44,7 +34,7 @@ class Duration:
 
 
 class ConnectionRecord:
-    def __init__(self, uri, handler="GRPC", conn_id=-1, pre_ping=False, **kwargs):
+    def __init__(self, uri, handler="GRPC", conn_id=-1, pre_ping=True, **kwargs):
         '''
         @param uri server uri
         @param recycle int, time period to recycle connection.
@@ -103,9 +93,9 @@ class ConnectionPool:
             status, version = conn.client().server_version(timeout=1)
             if not status.OK():
                 raise NotConnectError("Cannot check server version: {}".format(status.message))
-            if not _is_version_match(version):
+            if version not in support_versions:
                 raise VersionError(
-                    "Version of python SDK(v{}) not match that of server v{}, excepted is v{}".format(__version__,
+                    "Version of python SDK({}) not match that of server{}, excepted is {}".format(__version__,
                                                                                                   version,
                                                                                                   support_versions))
         conn.close()
