@@ -252,6 +252,11 @@ class Milvus:
         with self._connection() as handler:
             return handler.create_collection(collection_name, dim, index_file_size, metric_type, collection_param)
 
+    @check_connect
+    def create_hybrid_collection(self, collection_name, fields, timeout=10):
+        with self._connection() as handler:
+            return handler.create_hybrid_collection(collection_name, fields, timeout)
+
     @check_connect
     def has_collection(self, collection_name, timeout=10):
         """
@@ -354,6 +359,12 @@ class Milvus:
         with self._connection() as handler:
             return handler.preload_collection(collection_name, timeout)
 
+    @check_connect
+    def reload_segments(self, collection_name, segment_ids):
+        check_pass_param(collection_name=collection_name)
+        with self._connection() as handler:
+            return handler.reload_segments(collection_name, segment_ids)
+
     @check_connect
     def drop_collection(self, collection_name, timeout=10):
         """
@@ -416,6 +427,10 @@ class Milvus:
             return handler.insert(collection_name, records, ids, partition_tag, params, timeout, **kwargs)
 
     @check_connect
+    def insert_hybrid(self, collection_name, entities, vector_entities, ids=None, partition_tag=None, params=None):
+        with self._connection() as handler:
+            return handler.insert_hybrid(collection_name, entities, vector_entities, ids, partition_tag, params)
+
     def get_entity_by_id(self, collection_name, ids, timeout=None):
         """
         Returns raw vectors according to ids.
@@ -435,6 +450,11 @@ class Milvus:
         with self._connection() as handler:
             return handler.get_vectors_by_ids(collection_name, ids, timeout=timeout)
 
+    def get_hybrid_entity_by_id(self, collection_name, ids):
+        check_pass_param(collection_name=collection_name, ids=ids)
+        with self._connection() as handler:
+            return handler.get_hybrid_entity_by_id(collection_name, ids)
+
     @check_connect
     def list_id_in_segment(self, collection_name, segment_name, timeout=None):
         check_pass_param(collection_name=collection_name)
@@ -636,6 +656,16 @@ class Milvus:
         with self._connection() as handler:
             return handler.search(collection_name, top_k, query_records, partition_tags, params, timeout, **kwargs)
 
+    @check_connect
+    def search_hybrid_pb(self, collection_name, query_entities, partition_tags=None, params=None, **kwargs):
+        with self._connection() as handler:
+            return handler.search_hybrid_pb(collection_name, query_entities, partition_tags, params, **kwargs)
+
+    @check_connect
+    def search_hybrid(self, collection_name, vector_params, dsl, partition_tags=None, params=None, **kwargs):
+        with self._connection() as handler:
+            return handler.search_hybrid(collection_name, vector_params, dsl, partition_tags, params, **kwargs)
+
     @check_connect
     def search_in_segment(self, collection_name, file_ids, query_records, top_k, params=None, timeout=None, **kwargs):
         """
